# MIPHA

**Modular data Integration for Predictive Healthcare Analytics**

MIPHA is a framework allowing for the creation of reusable, transferable and highly-customizable machine learning models
for disease prediction. Its key features are:

- Flexible architecture allowing for the study of any disease
- Ability to include data from various sources
- Modular architecture designed for reusability

This framework is being worked on as part of my PhD research on disease prediction using machine learning.
Development is still in its early stages! Documentation of the library will be updated over time.

## Release summary

### [0.1.0] Initial prototype - 2024-07-25

#### Summary

This very first development allows for the instantiation of a disease prediction model, and will be built upon in subsequent iterations.

#### Added

- Initialize project
- Implement the core components of the framework
- Allow for saving, loading and reusing components of the framework
- Introduce unit tests and test utilities
- Set up continuous integration tools

#### Changed

#### Fixed